==> dwf-deploy-2.0.3.tgz: package/lib/dwfAsync.js <==
'use strict';

var logger = require('./logger.js');

const coContainerLib = require('./dwf/container.js');
const Result = require('./dwf/result.js').Result;

function indentSpaces(n) {
  var
    spaces = '',
    i;

  for (i = 0; i < n; i = i + 1) {
    spaces += ' ';
  }
  return spaces;
}

function printMessagesToConsole(logger, messages) {
  messages.forEach(function (message) {
    var
      indent,
      showDetails,
      id = '',
      locationRowCol = [],
      locationText = '';

    if (message.MESSAGE === 'END') {
      return;
    }

    indent = indentSpaces(message.LEVEL + 1);
    showDetails = message.SEVERITY === 'ERROR' || message.SEVERITY === 'WARNING';

    if (showDetails) {
      id = message.PLUGIN_ID;
      if (!id) {
        id = message.LIBRARY_ID;
      }

      var severity = (message.SEVERITY === 'ERROR') ? 'Error' : 'Warning';

      if (id) {
        logger.logVerbose('%s%s: %s: %s [%s]', indent, severity, id, message.MESSAGE, message.MESSAGE_CODE);
      } else {
        logger.logVerbose('%s%s: %s [%s]', indent, severity, message.MESSAGE, message.MESSAGE_CODE);
      }

      if (message.PATH) {
        if (message.LOCATION) {
          locationRowCol.push(message.LOCATION);
        }
        if (message.LOCATION_PATH) {
          locationRowCol.push(message.LOCATION_PATH);
        }
        if (locationRowCol.length !== 0) {
          locationText = '(' + locationRowCol.join(',') + ')';
        }
        logger.logVerbose('%s  at "%s" %s', indent, message.PATH, locationText);
      }

    } else {
      logger.logVerbose('%s%s', indent, message.MESSAGE);
    }

  });
}

function printMessagesToFile(logger, messages) {
  messages.forEach(function (message) {
    if (message.MESSAGE === 'END') {
      return;
    }

    var jsonObject = {
      id: 0,
      origin: 'server',
      request_id: message.REQUEST_ID,
      row_id: message.ROW_ID,
      level: message.LEVEL,
      type: message.TYPE,
      library_id: message.LIBRARY_ID,
      plugin_id: message.PLUGIN_ID,
      path: message.PATH,
      severity: message.SEVERITY,
      message_code: message.MESSAGE_CODE,
      message: message.MESSAGE,
      location: message.LOCATION,
      location_path: message.LOCATION_PATH,
      timestamp_utc: message.TIMESTAMP_UTC
    };

    logger.logToFile(jsonObject);
  });
}

function printMessages(logger, messages) {
  printMessagesToConsole(logger, messages);
  printMessagesToFile(logger, messages);
}

// print hdi stored procedure call result
function printResult(cb, parameters, messages) {
  printMessages(logger, messages);
  cb(null);
}

// check hdi stored procedure call result
function checkResult(phase, silent, expectedErrorMessageCodes) {
  return function (cb, parameters, messages) {
    if (parameters.RETURN_CODE >= 0) {
      if (!silent) {
        printMessages(logger, messages);
      }
      cb(null, {
        phase: phase,
        messages: messages
      });
      return;
    }

    // it's an error situation
    if (expectedErrorMessageCodes) {
      var foundMessageErrorCodes = 0;
      for (var i = 0; i < expectedErrorMessageCodes.length; ++i) {
        var expectedErrorMessageCode = expectedErrorMessageCodes[i];
        for (var j = 0; j < messages.length; ++j) {
          if (messages[j].MESSAGE_CODE === expectedErrorMessageCode) {
            ++foundMessageErrorCodes;
            break;
          }
        }
      }

      if (foundMessageErrorCodes === expectedErrorMessageCodes.length) {
        // ignore this error if all expected error message codes are in the messages
        cb(null, {
          phase: phase,
          messages: messages
        });
        return;
      }
    }

    printMessages(logger, messages);
    cb(new Error('DWF call failed'));
  };
}

module.exports = function (ioCredentials, ioOptions) {
  var credentials = ioCredentials;
  var options = ioOptions;

  function designToRuntime(iaaFiles) {
    return function (cb) {
      try {
        logger.trace('Create deployment container ...');
        let loContainer = new coContainerLib.Container(credentials, options, iaaFiles);
        logger.log('Create deployment container ... ok');

        logger.trace('Prepare step ...');
        let loResultPrepare = loContainer.prepare();
        if (loResultPrepare[Result.csKey_nStatus] === Result.cnSuccess) {
          logger.log('Prepare step ... ok');

          logger.trace('Create tasks step ...');
          let loResultPrepare_o_sExt2oValue = loResultPrepare[Result.csKey_o_sExt2oValue];
          let loResultCreateTasks = loContainer.createTasks(loResultPrepare_o_sExt2oValue);
          if (loResultCreateTasks[Result.csKey_nStatus] === Result.cnSuccess) {
            logger.log('Create tasks step ... ok');

            logger.trace('Run tasks step ...');
            let loResultCreateTasks_o_sExt2oValue = loResultCreateTasks[Result.csKey_o_sExt2oValue];
            loContainer.runTasks(loResultCreateTasks_o_sExt2oValue, function (ioError) {
              if (typeof ioError === 'undefined' || ioError === null) {
                logger.log('Run tasks step ... ok');
              }
              cb(ioError);
            });
          } else {
            cb(new Error('Failed, because the the create tasks step was not successful, but ' + JSON.stringify(loResultPrepare)));
          }
        } else {
          cb(new Error('Failed, because the the prepare step was not successful, but ' + JSON.stringify(loResultPrepare)));
        }
      } catch (e) {
        cb(e);
      }
    };
  }

  return {

    designToRuntime: designToRuntime,

    hdiPrintResult: printResult,

    hdiCheckResult: checkResult

  };
};

==> dwf-deploy-2.2.0.tgz: package/lib/dwfAsync.js <==
'use strict';

var logger = require('./logger.js');

const coContainerLib = require('./dwf/container.js');
const Result = require('./dwf/result.js').Result;
const coRepositoryLib = require('./dwf/repository.js');
const coAsyncLib = require('async');
function indentSpaces(n) {
  var
    spaces = '',
    i;

  for (i = 0; i < n; i = i + 1) {
    spaces += ' ';
  }
  return spaces;
}

function printMessagesToConsole(logger, messages) {
  messages.forEach(function (message) {
    var
      indent,
      showDetails,
      id = '',
      locationRowCol = [],
      locationText = '';

    if (message.MESSAGE === 'END') {
      return;
    }

    indent = indentSpaces(message.LEVEL + 1);
    showDetails = message.SEVERITY === 'ERROR' || message.SEVERITY === 'WARNING';

    if (showDetails) {
      id = message.PLUGIN_ID;
      if (!id) {
        id = message.LIBRARY_ID;
      }

      var severity = (message.SEVERITY === 'ERROR') ? 'Error' : 'Warning';

      if (id) {
        logger.logVerbose('%s%s: %s: %s [%s]', indent, severity, id, message.MESSAGE, message.MESSAGE_CODE);
      } else {
        logger.logVerbose('%s%s: %s [%s]', indent, severity, message.MESSAGE, message.MESSAGE_CODE);
      }

      if (message.PATH) {
        if (message.LOCATION) {
          locationRowCol.push(message.LOCATION);
        }
        if (message.LOCATION_PATH) {
          locationRowCol.push(message.LOCATION_PATH);
        }
        if (locationRowCol.length !== 0) {
          locationText = '(' + locationRowCol.join(',') + ')';
        }
        logger.logVerbose('%s  at "%s" %s', indent, message.PATH, locationText);
      }

    } else {
      logger.logVerbose('%s%s', indent, message.MESSAGE);
    }

  });
}

function printMessagesToFile(logger, messages) {
  messages.forEach(function (message) {
    if (message.MESSAGE === 'END') {
      return;
    }

    var jsonObject = {
      id: 0,
      origin: 'server',
      request_id: message.REQUEST_ID,
      row_id: message.ROW_ID,
      level: message.LEVEL,
      type: message.TYPE,
      library_id: message.LIBRARY_ID,
      plugin_id: message.PLUGIN_ID,
      path: message.PATH,
      severity: message.SEVERITY,
      message_code: message.MESSAGE_CODE,
      message: message.MESSAGE,
      location: message.LOCATION,
      location_path: message.LOCATION_PATH,
      timestamp_utc: message.TIMESTAMP_UTC
    };

    logger.logToFile(jsonObject);
  });
}

function printMessages(logger, messages) {
  printMessagesToConsole(logger, messages);
  printMessagesToFile(logger, messages);
}

// print hdi stored procedure call result
function printResult(cb, parameters, messages) {
  printMessages(logger, messages);
  cb(null);
}

// check hdi stored procedure call result
function checkResult(phase, silent, expectedErrorMessageCodes) {
  return function (cb, parameters, messages) {
    if (parameters.RETURN_CODE >= 0) {
      if (!silent) {
        printMessages(logger, messages);
      }
      cb(null, {
        phase: phase,
        messages: messages
      });
      return;
    }

    // it's an error situation
    if (expectedErrorMessageCodes) {
      var foundMessageErrorCodes = 0;
      for (var i = 0; i < expectedErrorMessageCodes.length; ++i) {
        var expectedErrorMessageCode = expectedErrorMessageCodes[i];
        for (var j = 0; j < messages.length; ++j) {
          if (messages[j].MESSAGE_CODE === expectedErrorMessageCode) {
            ++foundMessageErrorCodes;
            break;
          }
        }
      }

      if (foundMessageErrorCodes === expectedErrorMessageCodes.length) {
        // ignore this error if all expected error message codes are in the messages
        cb(null, {
          phase: phase,
          messages: messages
        });
        return;
      }
    }

    printMessages(logger, messages);
    cb(new Error('DWF call failed'));
  };
}

module.exports = function (ioCredentials, ioOptions) {
  var credentials = ioCredentials;
  var options = ioOptions;

  function designToRuntime(iaaFiles) {
    return function (cb) {
      try {
        let loContainer;
        let loRepository = new coRepositoryLib.Repository(credentials, options);

        // It's a GET call on  URL/repo/objects to get all .dwftaskchain files
        let deployedTaskChains = loRepository.get_afTask2Get('.dwftaskchain');
        coAsyncLib.waterfall(deployedTaskChains, function (err, res) {
          logger.trace('Create deployment container ...');
          let laResponseRepo = [];
          if(res && res.body && res.body.Result) {
            laResponseRepo = res.body.Result;
          }
          logger.log('Create deployment container ... ok');
         //creating an object of container.js and passing results(only resulted array of objects) of previous GET call on url/repo/objects
          loContainer = new coContainerLib.Container(credentials, options, iaaFiles, laResponseRepo);

          logger.trace('Prepare step ...');
          let loResultPrepare = loContainer.loResultPrepare;
          if (loResultPrepare[Result.csKey_nStatus] === Result.cnSuccess) {
            logger.log('Prepare step ... ok');

            logger.trace('Create tasks step ...');
            let loResultPrepare_o_sExt2oValue = loResultPrepare[Result.csKey_o_sExt2oValue];
            let loResultCreateTasks = loContainer.createTasks(loResultPrepare_o_sExt2oValue);
            if (loResultCreateTasks[Result.csKey_nStatus] === Result.cnSuccess) {
              logger.log('Create tasks step ... ok');

              logger.trace('Run tasks step ...');
              let loResultCreateTasks_o_sExt2oValue = loResultCreateTasks[Result.csKey_o_sExt2oValue];
              loContainer.runTasks(loResultCreateTasks_o_sExt2oValue, function (ioError) {
                if (typeof ioError === 'undefined' || ioError === null) {
                  logger.log('Run tasks step ... ok');
                }
                cb(ioError);
              });
            } else {
              cb(new Error('Failed, because the the create tasks step was not successful, but ' + JSON.stringify(loResultPrepare)));
            }
          } else {
            cb(new Error('Failed, because the the prepare step was not successful, but ' + JSON.stringify(loResultPrepare)));
          }
        });
      } catch (e) {
        cb(e);
      }
    };
  }

  return {

    designToRuntime: designToRuntime,

    hdiPrintResult: printResult,

    hdiCheckResult: checkResult

  };
};
